==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/ResponsivePhaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsivePhaseDescription } from "./ResponsivePhaseDescription";
/**
 * @hidden
 */
export let ResponsivePhaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsivePhaseDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsivePhaseDescriptionMetadata.a == null) {
                ResponsivePhaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsivePhaseDescriptionMetadata.c(ResponsivePhaseDescriptionMetadata.a);
            }
            if (a.k(ResponsivePhaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(ResponsivePhaseDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("DelayMilliseconds", "Number:int");
        }
        static d(a) {
            ResponsivePhaseDescriptionMetadata.b(a);
            a.ad("ResponsivePhase", () => new ResponsivePhaseDescription());
            a.ac("ResponsivePhase", ResponsivePhaseDescriptionMetadata.a);
        }
    }
    ResponsivePhaseDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsivePhaseDescriptionMetadata, 'ResponsivePhaseDescriptionMetadata');
    ResponsivePhaseDescriptionMetadata.a = null;
    return ResponsivePhaseDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/ResponsivePhaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsivePhaseDescription } from "./ResponsivePhaseDescription";
/**
 * @hidden
 */
export let ResponsivePhaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class ResponsivePhaseDescriptionMetadata extends Base {
        static b(a) {
            if (ResponsivePhaseDescriptionMetadata.a == null) {
                ResponsivePhaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ResponsivePhaseDescriptionMetadata.c(ResponsivePhaseDescriptionMetadata.a);
            }
            if (a.k(ResponsivePhaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(ResponsivePhaseDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Name", "String");
            a.item("DelayMilliseconds", "Number:int");
        }
        static d(a) {
            ResponsivePhaseDescriptionMetadata.b(a);
            a.ae("ResponsivePhase", () => new ResponsivePhaseDescription());
            a.ad("ResponsivePhase", ResponsivePhaseDescriptionMetadata.a);
        }
    }
    ResponsivePhaseDescriptionMetadata.$t = /*@__PURE__*/ markType(ResponsivePhaseDescriptionMetadata, 'ResponsivePhaseDescriptionMetadata');
    ResponsivePhaseDescriptionMetadata.a = null;
    return ResponsivePhaseDescriptionMetadata;
})();
